==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_ro.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ro" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disc ocupat, nu se poate demonta acum</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disc ocupat, nu se poate elimina acum</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Dispozitivul este ocupat, nu pot scoate acum</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Dispozitivul este ocupat, nu poate fi eliminat acum</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Volum</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Necunoascut</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Dispozitivul nu a fost îndepărtat în siguranță</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Clic pe „Eliminare sigură” și apoi deconectați data viitoare</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Dispozitivul este ocupat, nu pot scoate acum</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Dispozitivul este ocupat, nu poate fi eliminat acum</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Nu se poate demonta dispozitivul</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Discul este montat de către utilizatorul „%1”, nu îl puteți demonta.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Nu se poate găsi dispozitivul montat</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Discuri</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disc</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Deschide</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Scoateți toate</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Dispozitivul a fost îndepărtat în siguranță</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Acces interzis</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Nu aveți permisiunea de a accesa acest folder</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-file-manager_5.6.4.orig.tar.xz: dde-file-manager-5.6.4/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_ro.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ro">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Timpul de autentificare a expirat</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disc ocupat, nu poate fi demontat  la moment</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disc ocupat, nu  poate fi eliminat acum</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Dispozitivul este ocupat, nu poate  fi scos acum</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Dispozitivul este ocupat, nu poate fi eliminat acum</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Volum</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Necunoscut</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Dispozitivul nu a fost deconectat în mod sigur</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Clic pe „Eliminare sigură” și apoi deconectați data viitoare</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Dispozitivul nu poate fi deconectat</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Discul este montat de către utilizatorul „%1”, dvs. nu îl puteți demonta.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Nu se poate găsi dispozitivul montat</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Discuri</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disc</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Deschide</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Scoateți toate</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Dispozitivul a fost îndepărtat în  mod sigur</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Acces interzis</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Nu aveți permisiunea de a accesa acest directoriu</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Scanarea dispozitivului, oprire?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmare</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anulare</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Oprire</translation>
    </message>
</context>
</TS>
